==> estateplat-common-1.2.3-20180516.090746-86-sources.jar: cn/gtmap/estateplat/model/employment/subject/FcjyCyztCyrynjxx.java <==
package cn.gtmap.estateplat.model.employment.subject;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:haibingshuai@gtmap.cn">haibingshuai</a>
 * @version V1.1, 2018/04/24
 * @description 从业人员年检记录
 */
@Table(name = "fcjy_cyzt_cyrynjxx")
public class FcjyCyztCyrynjxx implements InsertVo {
    @Id
    private String rynjid;//主键
    private Long rynjbh;//年检记录编号
    private String rynjlx;//人员年检记录类型
    private Long rybh;//人员编号
    private String jlry;//记录人员
    private Date jlsj;//记录时间
    private String bz;//备注

    public String getRynjid() {
        return rynjid;
    }

    public void setRynjid(String rynjid) {
        this.rynjid = rynjid;
    }

    public Long getRynjbh() {
        return rynjbh;
    }

    public void setRynjbh(Long rynjbh) {
        this.rynjbh = rynjbh;
    }

    public String getRynjlx() {
        return rynjlx;
    }

    public void setRynjlx(String rynjlx) {
        this.rynjlx = rynjlx;
    }

    public Long getRybh() {
        return rybh;
    }

    public void setRybh(Long rybh) {
        this.rybh = rybh;
    }

    public String getJlry() {
        return jlry;
    }

    public void setJlry(String jlry) {
        this.jlry = jlry;
    }

    public Date getJlsj() {
        return jlsj;
    }

    public void setJlsj(Date jlsj) {
        this.jlsj = jlsj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }
}

==> estateplat-common-1.2.3-20180704.121829-135-sources.jar: cn/gtmap/estateplat/model/employment/subject/FcjyCyztCyrynjxx.java <==
package cn.gtmap.estateplat.model.employment.subject;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:haibingshuai@gtmap.cn">haibingshuai</a>
 * @version V1.1, 2018/04/24
 * @description 从业人员年检记录
 */
@Table(name = "fcjy_cyzt_cyrynjxx")
public class FcjyCyztCyrynjxx implements InsertVo {
    @Id
    private String rynjid;//主键
    private Long rynjbh;//年检记录编号
    private String rynjlx;//人员年检记录类型
    private String rybh;//人员编号
    private String jlry;//记录人员
    private Date jlsj;//记录时间
    private String bz;//备注

    public String getRynjid() {
        return rynjid;
    }

    public void setRynjid(String rynjid) {
        this.rynjid = rynjid;
    }

    public Long getRynjbh() {
        return rynjbh;
    }

    public void setRynjbh(Long rynjbh) {
        this.rynjbh = rynjbh;
    }

    public String getRynjlx() {
        return rynjlx;
    }

    public void setRynjlx(String rynjlx) {
        this.rynjlx = rynjlx;
    }

    public String getRybh() {
        return rybh;
    }

    public void setRybh(String rybh) {
        this.rybh = rybh;
    }

    public String getJlry() {
        return jlry;
    }

    public void setJlry(String jlry) {
        this.jlry = jlry;
    }

    public Date getJlsj() {
        return jlsj;
    }

    public void setJlsj(Date jlsj) {
        this.jlsj = jlsj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }
}
